macro_rules! defer {
($function:expr) => { ... };
($tree:expr, $function:expr) => { ... };
}Expand description
Calls function with argument, tree, at the end of the current scope
The function will only be executed if the tree is enabled when this macro is called